import processing.serial.*;

/** Bouncing Ball Serial Example
 *  Tiffany Tseng
 *  Description: Potentiometer input from the Arduino controls the speed of a bouncing ball
 *               When the ball hits a 'wall,' a light on the Arduino lights up
 *  Last Updated: 1/22/15
 */


Serial myPort;
float potValue = 0;

int rad = 60;        // Width of the shape
float xpos, ypos;    // Starting position of shape    

float xspeed = 2.8;  // Speed of the shape
float yspeed = 2.2;  // Speed of the shape

int xdirection = 1;  // Left or Right
int ydirection = 1;  // Top to Bottom


void setup() 
{
  size(displayWidth/2, displayHeight);
  noStroke();
  frameRate(30);
  ellipseMode(RADIUS);
  // Set the starting position of the shape
  xpos = width/2;
  ypos = height/2;
  println(Serial.list());
  myPort = new Serial(this, Serial.list()[7], 9600); // change the serial port based on your computer
  myPort.bufferUntil('\n');
}

void draw() 
{
  background(102);
  
  // Update the position of the shape
  xpos = xpos + ( xspeed * xdirection );
  ypos = ypos + ( yspeed * ydirection );
  
  // Test to see if the shape exceeds the boundaries of the screen
  // If it does, reverse its direction by multiplying by -1
  if (xpos > width-rad || xpos < rad) {
    xdirection *= -1;
    myPort.write('H');
  }
  else if (ypos > height-rad || ypos < rad) {
    ydirection *= -1;
    myPort.write('H');
  }
  else{
    myPort.write('0');
  }

  // Draw the shape
  ellipse(xpos, ypos, rad, rad);
}

void serialEvent(Serial p) {
  String val = p.readString();
  println(val);
  if (val != null) {
    potValue = float(val);
    xspeed = map(potValue,0,1023,1,50);
  }
}
